@@ -22,8 +22,9 @@ Usage::
     list_targets_paginator: ListTargetsPaginator = client.get_paginator("list_targets")
     ```
 """
-from typing import Iterator, List
+from typing import Generic, Iterator, List, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
@@ -39,9 +40,19 @@ from .type_defs import (
 __all__ = ("ListEventTypesPaginator", "ListNotificationRulesPaginator", "ListTargetsPaginator")
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListEventTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listeventtypespaginator)
     """
 
@@ -50,16 +61,16 @@ class ListEventTypesPaginator(Boto3Paginator):
         *,
         Filters: List["ListEventTypesFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListEventTypesResultTypeDef]:
+    ) -> _PageIterator[ListEventTypesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listeventtypespaginator)
         """
 
 
 class ListNotificationRulesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listnotificationrulespaginator)
     """
 
@@ -68,16 +79,16 @@ class ListNotificationRulesPaginator(Boto3Paginator):
         *,
         Filters: List["ListNotificationRulesFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListNotificationRulesResultTypeDef]:
+    ) -> _PageIterator[ListNotificationRulesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listnotificationrulespaginator)
         """
 
 
 class ListTargetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listtargetspaginator)
     """
 
@@ -86,8 +97,8 @@ class ListTargetsPaginator(Boto3Paginator):
         *,
         Filters: List["ListTargetsFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTargetsResultTypeDef]:
+    ) -> _PageIterator[ListTargetsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listtargetspaginator)
         """
